@@ -62,6 +62,10 @@ def web_tiddler_url(environ, tiddler, container='bags', full=True):
 
     Do this all the time, so that we get the right URIs even
     when working around ControlView.
+
+    If the bag does not fit in a space, then make is URI be at
+    the server_host domain. If/when auxbags are made to work this
+    will need to be reviewed.
     """
     if '_canonical_uri' in tiddler.fields:
         return tiddler.fields['_canonical_uri']
@@ -72,17 +76,19 @@ def web_tiddler_url(environ, tiddler, container='bags', full=True):
             space_name = Space.name_from_recipe(tiddler.recipe)
         else:
             space_name = Space.name_from_bag(tiddler.bag)
+        space_name = space_name + '.'
+    except ValueError, exc:
+        space_name = ''
+
+    host = environ['tiddlyweb.config']['server_host']['host']
+    port = environ['tiddlyweb.config']['server_host']['port']
+    if port is '443' or port is '80':
+        port = ''
+    else:
+        port = ':%s' % port
+    environ['HTTP_HOST'] = '%s%s%s' % (space_name.encode('utf-8'),
+        host, port)
 
-        host = environ['tiddlyweb.config']['server_host']['host']
-        port = environ['tiddlyweb.config']['server_host']['port']
-        if port is '443' or port is '80':
-            port = ''
-        else:
-            port = ':%s' % port
-        environ['HTTP_HOST'] = '%s.%s%s' % (space_name.encode('utf-8'),
-            host, port)
-    except ValueError:
-        pass
     url = original_tiddler_url(environ, tiddler, container, full)
     if saved_host:
         environ['HTTP_HOST'] = saved_host
